@@ -1,12 +1,12 @@
 # uWSGI build system
 
-uwsgi_version = '2.0.15'
+uwsgi_version = '2.0.17'
 
 import os
 import re
 import time
 uwsgi_os = os.uname()[0]
-uwsgi_os_k = re.split('[-+]', os.uname()[2])[0]
+uwsgi_os_k = re.split('[-+_]', os.uname()[2])[0]
 uwsgi_os_v = os.uname()[3]
 uwsgi_cpu = os.uname()[4]
 
@@ -385,9 +385,13 @@ def build_uwsgi(uc, print_only=False, gcll=None):
     if additional_sources:
         for item in additional_sources.split(','):
             gcc_list.append(item)
-    
-    cflags.append('-DUWSGI_CFLAGS=\\"%s\\"' % uwsgi_cflags)
-    cflags.append('-DUWSGI_BUILD_DATE="\\"%s\\""' % time.strftime("%d %B %Y %H:%M:%S"))
+
+    if uc.filename.endswith('coverity.ini'):
+        cflags.append('-DUWSGI_CFLAGS=\\"\\"')
+    else:
+        cflags.append('-DUWSGI_CFLAGS=\\"%s\\"' % uwsgi_cflags)
+    build_date = int(os.environ.get('SOURCE_DATE_EPOCH', time.time()))
+    cflags.append('-DUWSGI_BUILD_DATE="\\"%s\\""' % time.strftime("%d %B %Y %H:%M:%S", time.gmtime(build_date)))
 
     post_build = []
 
@@ -635,6 +639,7 @@ class uConf(object):
     def __init__(self, filename, mute=False):
         global GCC
 
+        self.filename = filename
         self.config = ConfigParser.ConfigParser()
         if not mute:
             print("using profile: %s" % filename)
@@ -826,7 +831,7 @@ class uConf(object):
             self.cflags.append('-DUWSGI_HAS_IFADDRS')
             report['ifaddrs'] = True
 
-        if uwsgi_os in ('FreeBSD', 'OpenBSD'):
+        if uwsgi_os in ('FreeBSD', 'DragonFly', 'OpenBSD'):
             if self.has_include('execinfo.h') or os.path.exists('/usr/local/include/execinfo.h'):
                 if os.path.exists('/usr/local/include/execinfo.h'):
                     self.cflags.append('-I/usr/local/include')
@@ -1295,7 +1300,7 @@ class uConf(object):
         if self.get('xml'):
             if self.get('xml') == 'auto':
                 xmlconf = spcall('xml2-config --libs')
-                if xmlconf:
+                if xmlconf and uwsgi_os != 'Darwin':
                     self.libs.append(xmlconf)
                     xmlconf = spcall("xml2-config --cflags")
                     self.cflags.append(xmlconf)
